==> lxqt-powermanagement_0.14.1.orig.tar.xz: lxqt-powermanagement-0.14.1/src/translations/lxqt-powermanagement_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="42"/>
        <source>Empty</source>
        <translation>Baleira</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Discharging</source>
        <translation>Descargando</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Fully charged</source>
        <translation>Totalmente cargada</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="49"/>
        <source>Charging</source>
        <translation>Cargando</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="58"/>
        <source>Lithium ion</source>
        <translation>Ións de litio</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium polymer</source>
        <translation>Polímero de litio</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium iron phosphate</source>
        <translation>Litio-ferrofosfato</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lead acid</source>
        <translation>Chumbo e ácido</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Nickel cadmium</source>
        <translation>Níquel-cadmio</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel metal hydride</source>
        <translation>Níquel-metal hidruro</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="71"/>
        <source>Unknown</source>
        <translation>Descoñecida</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="80"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Batería de computador de peto (PDA)</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Batería de sistema de alimentación ininterrompida (UPS)</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Primary battery</source>
        <translation>Batería principal</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Mouse battery</source>
        <translation>Batería de rato</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Keyboard battery</source>
        <translation>Batería de teclado</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Batería de teclado e de rato</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Camera battery</source>
        <translation>Batería de cámara</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Phone battery</source>
        <translation>Batería de teléfono</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Monitor battery</source>
        <translation>Batería de monitor</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="99"/>
        <source>Unknown battery</source>
        <translation>Batería descoñecida</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>Información da batería</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Xestión da enerxía</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Temperatura:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Enerxía total teórica:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Carga completa:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Carga actual:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Taxa de carga:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Tecnoloxía:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Voltaxe:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Fabricante:</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>Sen batería!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQt non foi quen de atopar datos sobre ningunha batería - desactivouse a supervisión</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="114"/>
        <source>Power low!</source>
        <translation>Carga baixa!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="126"/>
        <source>Suspending in %n second(s)</source>
        <translation>
            <numerusform>Suspenderase nun segundo</numerusform>
            <numerusform>Suspenderase en %n segundos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="129"/>
        <source>Hibernating in %n second(s)</source>
        <translation>
            <numerusform>Hibernará nun segundo</numerusform>
            <numerusform>Hibernará en %n segundos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="132"/>
        <source>Shutting down in %n second(s)</source>
        <translation>
            <numerusform>Apagarase nun segundo</numerusform>
            <numerusform>Apagarase en %n segundos</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="112"/>
        <source>Power Management</source>
        <translation>Xestión da enerxía</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="113"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Está executando por primeira vez a xestión de enerxía do LXQt.
Pode configurala a partires dos axustes... </translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="114"/>
        <source>Configure...</source>
        <translation>Configurar...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="61"/>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="63"/>
        <location filename="../trayicon.cpp" line="94"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="65"/>
        <source>Disable icon</source>
        <translation>Desactivar a icona</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="95"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;Xestión de enerxía do LXQt&lt;/b&gt;&lt;br/&gt;  - Xestión de enerxía do contorno de escritorio LXQt&lt;/p&gt;&lt;p&gt;  Autores:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - e outras persoas dos proxectos Razor e LXQt&lt;/p&gt;&lt;p&gt;  Dereitos de autoría &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="113"/>
        <source>LXQt Power Management info</source>
        <translation>Información da xestión de enerxía do LXQt</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="114"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>Pode (re)activar a icona da xestión de enerxía do LXQt na área de notificación en &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="116"/>
        <source>Configure now</source>
        <translation>Configurala agora</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement_0.17.1.orig.tar.xz: lxqt-powermanagement-0.17.1/src/translations/lxqt-powermanagement_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../batteryhelper.cpp" line="42"/>
        <source>Empty</source>
        <translation>Baleira</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="44"/>
        <source>Discharging</source>
        <translation>Descargando</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="46"/>
        <source>Fully charged</source>
        <translation>Totalmente cargada</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="49"/>
        <source>Charging</source>
        <translation>Cargando</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="58"/>
        <source>Lithium ion</source>
        <translation>Ións de litio</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="60"/>
        <source>Lithium polymer</source>
        <translation>Polímero de litio</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="62"/>
        <source>Lithium iron phosphate</source>
        <translation>Litio-ferrofosfato</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="64"/>
        <source>Lead acid</source>
        <translation>Chumbo e ácido</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="66"/>
        <source>Nickel cadmium</source>
        <translation>Níquel-cadmio</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="68"/>
        <source>Nickel metal hydride</source>
        <translation>Níquel-metal hidruro</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="71"/>
        <source>Unknown</source>
        <translation>Descoñecida</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="80"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>Batería de computador de peto (PDA)</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="82"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Batería de sistema de alimentación ininterrompida (UPS)</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="84"/>
        <source>Primary battery</source>
        <translation>Batería principal</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="86"/>
        <source>Mouse battery</source>
        <translation>Batería de rato</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="88"/>
        <source>Keyboard battery</source>
        <translation>Batería de teclado</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="90"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Batería de teclado e de rato</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="92"/>
        <source>Camera battery</source>
        <translation>Batería de cámara</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="94"/>
        <source>Phone battery</source>
        <translation>Batería de teléfono</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="96"/>
        <source>Monitor battery</source>
        <translation>Batería de monitor</translation>
    </message>
    <message>
        <location filename="../batteryhelper.cpp" line="99"/>
        <source>Unknown battery</source>
        <translation>Batería descoñecida</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Diálogo</translation>
    </message>
    <message>
        <location filename="../batteryinfodialog.cpp" line="24"/>
        <source>Battery Info</source>
        <translation>Información da batería</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Xestión da enerxía</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Temperatura:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Enerxía total teórica:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Carga completa:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Carga actual:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Taxa de carga:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Tecnoloxía:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Voltaxe:</translation>
    </message>
    <message>
        <location filename="../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Fabricante:</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../batterywatcher.cpp" line="48"/>
        <source>No battery!</source>
        <translation>Sen batería!</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="49"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>LXQt non foi quen de atopar datos sobre ningunha batería - desactivouse a supervisión</translation>
    </message>
    <message>
        <location filename="../batterywatcher.cpp" line="114"/>
        <source>Power low!</source>
        <translation>Carga baixa!</translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="126"/>
        <source>Suspending in %n second(s)</source>
        <translation>
            <numerusform>Suspenderase nun segundo</numerusform>
            <numerusform>Suspenderase en %n segundos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="129"/>
        <source>Hibernating in %n second(s)</source>
        <translation>
            <numerusform>Hibernará nun segundo</numerusform>
            <numerusform>Hibernará en %n segundos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../batterywatcher.cpp" line="132"/>
        <source>Shutting down in %n second(s)</source>
        <translation>
            <numerusform>Apagarase nun segundo</numerusform>
            <numerusform>Apagarase en %n segundos</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PowerButton</name>
    <message>
        <location filename="../powerbutton.cpp" line="72"/>
        <source>Power off key action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="79"/>
        <source>Suspend key action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerbutton.cpp" line="86"/>
        <source>Hibernate key action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../powermanagementd.cpp" line="115"/>
        <source>Power Management</source>
        <translation>Xestión da enerxía</translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="116"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Está executando por primeira vez a xestión de enerxía do LXQt.
Pode configurala a partires dos axustes... </translation>
    </message>
    <message>
        <location filename="../powermanagementd.cpp" line="117"/>
        <source>Configure...</source>
        <translation>Configurar...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../trayicon.cpp" line="60"/>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="62"/>
        <location filename="../trayicon.cpp" line="93"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="64"/>
        <source>Disable icon</source>
        <translation>Desactivar a icona</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="94"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;Xestión de enerxía do LXQt&lt;/b&gt;&lt;br/&gt;  - Xestión de enerxía do contorno de escritorio LXQt&lt;/p&gt;&lt;p&gt;  Autores:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - e outras persoas dos proxectos Razor e LXQt&lt;/p&gt;&lt;p&gt;  Dereitos de autoría &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="112"/>
        <source>LXQt Power Management info</source>
        <translation>Información da xestión de enerxía do LXQt</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="113"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>Pode (re)activar a icona da xestión de enerxía do LXQt na área de notificación en &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../trayicon.cpp" line="115"/>
        <source>Configure now</source>
        <translation>Configurala agora</translation>
    </message>
</context>
</TS>
